@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-01-28'; # DATE
-our $VERSION = '0.83'; # VERSION
+our $DATE = '2015-02-06'; # DATE
+our $VERSION = '0.84'; # VERSION
 
 use 5.010;
 use strict;
@@ -14,7 +14,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(test_run test_complete);
 
-our $CLASS = "Perinci::CmdLine";
+our $CLASS = "Perinci::CmdLine::Lite";
 
 sub test_run {
     my %args = @_;
@@ -112,7 +112,7 @@ sub test_complete {
 }
 
 1;
-# ABSTRACT: Test library for Perinci::CmdLine{,::Lite}
+# ABSTRACT: Test library for Perinci::CmdLine{::Classic,::Lite}
 
 __END__
 
@@ -122,11 +122,11 @@ __END__
 
 =head1 NAME
 
-Test::Perinci::CmdLine - Test library for Perinci::CmdLine{,::Lite}
+Test::Perinci::CmdLine - Test library for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.83 of Test::Perinci::CmdLine (from Perl distribution Perinci-CmdLine-Lite), released on 2015-01-28.
+This document describes version 0.84 of Test::Perinci::CmdLine (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-06.
 
 =head1 FUNCTIONS
 
